<no title> — CALCEPH - Fortran 2003 language 3.4.1 documentation

    integer*8 peph
    integer res
    real(8) jd0
    real(8) dt1, dt2
    real(8) PV(6)
    TYPE(C_PTR) :: peph

    jd0 = 2442457
    dt1 = 0.5D0
    dt2 = 0.9D0
    peph = calceph_open("example1.dat"//C_NULL_CHAR)
    if (C_ASSOCIATED(peph)) then

       ! the heliocentric coordinates of Mars
       res = calceph_compute(peph,jd0, dt1, 4, 11, PV)
       write(*,*) PV

       res = calceph_compute(peph,jd0, dt2, 4, 11, PV)
       write(*,*) PV

        call calceph_close(peph)
     endif